.. currentmodule:: gorilla

.. _utilities:

Utilities
=========

.. autosummary::
   :nosignatures:

   default_filter
   create_patches
   find_patches
   get_attribute
   get_original_attribute
   DecoratorData
   get_decorator_data


----

.. autofunction:: default_filter

----

.. autofunction:: create_patches

----

.. autofunction:: find_patches

----

.. autofunction:: get_attribute

----

.. autofunction:: get_original_attribute

----

.. autoclass:: DecoratorData
   :members:
   :special-members: __init__

----

.. autofunction:: get_decorator_data
